@@ -8,6 +8,7 @@ ToDo:
     * Find out why `extra=Extra.allow` causes mypy to fail. Seems like a bug in pydantic.
 """
 from datetime import date, datetime
+from enum import Enum
 from typing import List, Optional
 
 from pydantic import BaseModel, Extra, Field
@@ -22,7 +23,7 @@ class Me(BaseModel):
 
 class MultiLingualStr(BaseModel, extra=Extra.allow):  # type: ignore
     # ToDo: Add here more available languages, not mentioned in the API
-    en: Optional[str]
+    en: Optional[str]  # we assume though that english is always given to simplify things
     de: Optional[str]
 
 
@@ -99,6 +100,16 @@ class Resource(BaseModel):
     description: str
 
 
+class State(Enum):
+    submitted = "submitted"
+    accepted = "accepted"
+    rejected = "rejected"  # is "Not accepted" in WebUI
+    confirmed = "confirmed"
+    withdrawn = "withdrawn"
+    canceled = "canceled"
+    deleted = "deleted"
+
+
 class Submission(BaseModel):
     code: str
     speakers: List[SubmissionSpeaker]
@@ -108,8 +119,8 @@ class Submission(BaseModel):
     submission_type_id: int
     track: Optional[MultiLingualStr]
     track_id: Optional[int]
-    state: str
-    pending_state: Optional[str]  # needs organizer permissions
+    state: State
+    pending_state: Optional[State]  # needs organizer permissions
     abstract: str
     description: str
     duration: Optional[int]
@@ -139,7 +150,7 @@ class User(BaseModel):
 class Review(BaseModel):
     id: int
     submission: str
-    user: str  # but says 'name' and 'email' in the API docs
+    user: str
     text: Optional[str]
     score: Optional[float]  # converted from str if present
     created: datetime
@@ -162,13 +173,19 @@ class Room(BaseModel):
     availabilities: Optional[List[RoomAvailability]]  # needs organizer permissions
 
 
+class QuestionRequirement(Enum):
+    optional = "optional"
+    required = "required"
+    after_deadline = "after deadline"
+
+
 class Question(BaseModel):
     id: int
     variant: str
     target: str
     question: MultiLingualStr
     help_text: MultiLingualStr
-    question_required: str  # from [optional, required, after_deadline] ToDo: handle as enum?
+    question_required: QuestionRequirement
     deadline: Optional[datetime]
     required: bool
     read_only: Optional[bool]
